window.Gleam.initSearch([{"doc":"trellis","title":"trellis","content":"# trellis\n\nA simple Gleam library for pretty printing tabular data!\n\n[![Package Version](https://img.shields.io/hexpm/v/trellis)](https://hex.pm/packages/trellis)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/trellis/)\n\n```sh\ngleam add trellis@1\n```\n```gleam\nimport trellis\n\npub fn main() {\n  let names = [&quot;Michael&quot;, &quot;Vitor&quot;, &quot;Ellen&quot;]\n\n  let data = {\n    use _ &lt;- list.map(list.range(0, 10))\n\n    let assert Ok(name) = names |&gt; list.shuffle |&gt; list.first\n    let age = int.random(80)\n    let happy = int.random(2) |&gt; int.is_even\n\n    Row(name:, age:, happy:)\n  }\n\n  trellis.table(data:)\n  |&gt; trellis.style(style.Round)\n  |&gt; trellis.with(&quot;name&quot;, Left, {\n    use Row(name:, age: _, happy: _) &lt;- trellis.param\n    name\n  })\n  |&gt; trellis.with(&quot;the person&#39;s age&quot;, Center, {\n    use Row(name: _, age:, happy: _) &lt;- trellis.param\n    age |&gt; int.to_string\n  })\n  |&gt; trellis.with(&quot;senior&quot;, Right, {\n    use Row(name: _, age:, happy: _) &lt;- trellis.param\n    { age &gt;= 65 } |&gt; bool.to_string\n  })\n  |&gt; trellis.with(&quot;happy&quot;, Right, {\n    use Row(name: _, age: _, happy:) &lt;- trellis.param\n    case happy {\n      True -&gt; &quot;Happy&quot;\n      False -&gt; &quot;Not Happy&quot;\n    }\n  })\n  |&gt; trellis.to_string\n  |&gt; io.println\n}\n```\n\nThe output looks like:\n&lt;pre&gt;&lt;code style=&quot;font-family: monospace;&quot; class=&quot;language-plaintext&quot;&gt;\n╭───────────┬──────────────────┬────────┬───────────╮\n│   name    │ the person&#39;s age │ senior │   happy   │\n├───────────┼──────────────────┼────────┼───────────┤\n│ Michael   │        16        │  False │ Not Happy │\n│ Vitor     │        54        │  False │     Happy │\n│ Ellen     │        63        │  False │ Not Happy │\n│ Ellen     │        19        │  False │ Not Happy │\n│ Vitor     │        28        │  False │     Happy │\n│ Michael   │        59        │  False │ Not Happy │\n│ Ellen     │        60        │  False │     Happy │\n│ Vitor     │        60        │  False │ Not Happy │\n│ Michael   │        74        │   True │     Happy │\n│ Vitor     │        12        │  False │     Happy │\n│ Ellen     │        16        │  False │     Happy │\n╰───────────┴──────────────────┴────────┴───────────╯\n&lt;/code&gt;&lt;/pre&gt;\n\nFurther documentation can be found at &lt;https://hexdocs.pm/trellis&gt;.\n\n## Development\n\n```sh\nnix develop # start dev shell\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"trellis/style","title":"Style","content":"pub type Style {\n  Line\n  Round\n}\n\nLine\n\n\nRound\n\n\nSynonyms:\ntrellis/style.Style\ntrellis/style Style","url":"trellis/style.html#Style"},{"doc":"trellis/style","title":"style","content":"pub fn style(style style: Style) -&gt; StyleGuide\n\nSynonyms:\ntrellis/style.style\ntrellis/style style","url":"trellis/style.html#style"},{"doc":"trellis/style","title":"trellis/style","content":"","url":"trellis/style.html"},{"doc":"trellis","title":"Align","content":"pub type Align {\n  Left\n  Right\n  Center\n}\n Alignment options for column content\nLeft\n\n\nRight\n\n\nCenter\n\n\nSynonyms:\ntrellis.Align\ntrellis Align","url":"trellis.html#Align"},{"doc":"trellis","title":"Column","content":"pub type Column(value) {\n  Column(\n    header: String,\n    align: Align,\n    getter: fn(value) -&gt; String,\n  )\n}\n A type representing a column in the table with header, alignment, and value getter\nColumn(header: String, align: Align, getter: fn(value) -&gt; String)\n\n\nSynonyms:\ntrellis.Column\ntrellis Column","url":"trellis.html#Column"},{"doc":"trellis","title":"Table","content":"pub type Table(value) {\n  Table(\n    columns: List(Column(value)),\n    rows: List(value),\n    style: style.Style,\n  )\n}\n A type representing a formatted table with headers and rows of data\n \n ## Example\n \n \n let table = \n   table([user1, user2, user3])\n   |&gt; with(&quot;Name&quot;, Left, { \n     use user &lt;- param\n     user.name \n   })\n   |&gt; with(&quot;Age&quot;, Right, {\n     use user &lt;- param\n     user.age |&gt; int.to_string\n   })\n \nTable(\n  columns: List(Column(value)),\n  rows: List(value),\n  style: style.Style,\n)\n\n\nSynonyms:\ntrellis.Table\ntrellis Table","url":"trellis.html#Table"},{"doc":"trellis","title":"param","content":"pub fn param(f: fn(a) -&gt; b) -&gt; fn(a) -&gt; b\n Helper function to wrap a function for use in column definitions\n \n This is a utility function that can make column definitions more readable\n when used with partial application\nSynonyms:\ntrellis.param\ntrellis param","url":"trellis.html#param"},{"doc":"trellis","title":"style","content":"pub fn style(\n  table table: Table(a),\n  style style: Style,\n) -&gt; Table(a)\n Set the style of the table\nSynonyms:\ntrellis.style\ntrellis style","url":"trellis.html#style"},{"doc":"trellis","title":"table","content":"pub fn table(data rows: List(a)) -&gt; Table(a)\n Creates a new table with the given rows of data\nSynonyms:\ntrellis.table\ntrellis table","url":"trellis.html#table"},{"doc":"trellis","title":"to_string","content":"pub fn to_string(table: Table(a)) -&gt; String\n Converts the table to a formatted string representation\n \n Creates a string with Unicode box-drawing characters, properly aligned content,\n and separators between header and rows\nSynonyms:\ntrellis.to_string\ntrellis to_string","url":"trellis.html#to_string"},{"doc":"trellis","title":"with","content":"pub fn with(\n  table table: Table(a),\n  header header: String,\n  align align: Align,\n  getter getter: fn(a) -&gt; String,\n) -&gt; Table(a)\n Adds a new column to the table definition\nSynonyms:\ntrellis.with\ntrellis with","url":"trellis.html#with"},{"doc":"trellis","title":"trellis","content":"","url":"trellis.html"}]);